<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name/>
    <message>
        <source>Delete</source>
        <translation type="vanished">Elimina</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Tutto schermo</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Presentazione</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Esporta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copia</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Agg. ai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Imposta come sfondo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Visualizza nel File Manager</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Info immagine</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Video info</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Ripristina</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Nuovo Album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Sicuro di voler eliminare questo album?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Oppure trascina le immagini qui</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importa tutti</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importa in:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disco di Sistema</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleria</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disco occupato, impossibile espellere al momento</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>I file verranno eliminati definitivamente dopo i giorni indicati</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salva in:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualità:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Seleziona un altro percorso</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Il nome non può essere vuoto</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>esiste già, desideri sostituirla?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>Dispositivo %1</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Cancella disco %1</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 crittografato</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Esporta Immagini</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Eliminazione...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Ripristino in corso...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation type="vanished">Sei sicuro di eliminare questa foto dall&apos;album?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="vanished">Sei sicuro di eliminare questo video dall&apos;album?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Info base</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 immagine</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>%n elementi</numerusform><numerusform>%n elementi</numerusform></translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importa foto e video</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>oppure trascinali qui</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Tutte le immagini e video</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nessuna immagine o video trovati</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleria</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Album è un gestore per la visualizzazione e l&apos;organizzazione di foto e video.
Localizzazione italiana a cura di Massimo A. Carofano</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tutto schermo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel File Manager</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come sfondo</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Successiva</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Agg. ai preferiti</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sposta dai preferiti</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Rinomina album</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album “%1” rimosso</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Aggiunta con successo in “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Import completato</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Import fallito</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Esporazione fallita</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Esportazione completata</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Tutte le immagini</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Linea del tempo</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Esci da schermo intero/presentazione</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Seleziona tutte</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom più</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom meno</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina su</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina giu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importazione...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Tutte le immagini e video</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importa foto e video</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nessuna immagine o video trovati</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Esporta foto</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Importa foto/video</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Info Foto/Video</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Importa foto e video</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dimensione file</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data acquisizione</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data modifica</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modalità esposizione</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programma esposizione</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo di esposizione</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Lunghezza focale</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura massima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modalità di misurazione</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Bilanciamento del bianco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensazione del flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modello fotocamera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modello lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spazio colore</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Nessun risultato</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disco di Sistema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Deseleziona</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importati in</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importati in</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Deseleziona tutto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tutto</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Agg. ai preferiti</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importazione...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 elementi importati</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 elementi eliminati</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 elementi importati, %2 import falliti</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 immagine selezionata</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 video selezionato</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>L&apos;immagine/video esiste già</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation><numerusform>%n immagini selezionate</numerusform><numerusform>%n immagini selezionate</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation><numerusform>%n video selezionati</numerusform><numerusform>%n video selezionati</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation><numerusform>%n elementi selezionati</numerusform><numerusform>%n elementi selezionati</numerusform></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 elementi importati, %2 elementi già presenti</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Risultati di ricerca</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 immagine trovata</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation><numerusform>%n video trovati</numerusform><numerusform>%n video trovati</numerusform></translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 video trovato</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation><numerusform>%n elementi trovati</numerusform><numerusform>%n elementi trovati</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation><numerusform>%n foto trovate</numerusform><numerusform>%n foto trovate</numerusform></translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 immagine</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Importazione: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Esportazione: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tutto schermo</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Agg. ai preferiti</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sposta dai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel File Manager</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come sfondo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Aggiungi all&apos;album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Rimuovi dall&apos;album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video info</translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 immagine</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>%n elementi</numerusform><numerusform>%n elementi</numerusform></translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Info base</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Codec info</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Audio info</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Video CodecID</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Video CodeRate</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Proporzione</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Audio CodecID</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Audio CodeRate</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Audio digit</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Campionamento</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data modifica</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dimensione file</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Percorso</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video info</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data acquisizione</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
</TS>